# NEVER EDIT this file.  It was generated and will be overwritten without
# notice upon regeneration of this application.  You have been warned.
package JobAd::Model::auth_users;
use strict; use warnings;

__PACKAGE__->load_components( qw/ PK::Auto Core / );
__PACKAGE__->table( 'auth_users' );
__PACKAGE__->add_columns( qw/
    id
    user_id
    active
    user_name
    passwd
    crypt
    first_name
    last_name
    email
/ );
__PACKAGE__->set_primary_key( 'user_id' );
__PACKAGE__->base_model( 'JobAd::Model' );

sub get_foreign_display_fields {
    return [ qw( last_name first_name ) ];
}

sub get_foreign_tables {
    return qw(
    );
}

sub foreign_display {
    my $self = shift;

    my $last_name = $self->last_name() || '';
    my $first_name = $self->first_name() || '';

    return "$last_name, $first_name";
}

sub table_name {
    return 'auth_users';
}

1;

=head1 NAME

JobAd::Model::GEN::auth_users - model for auth_users table (generated part)

=head1 DESCRIPTION

This model inherits from Gantry::Utils::DBIxClass.
It was generated by Bigtop, and IS subject to regeneration.

=head1 METHODS

You may use all normal Gantry::Utils::DBIxClass methods and the
ones listed here:

=over 4

=item get_foreign_display_fields

=item get_foreign_tables

=item foreign_display

=item table_name

=back

=cut
