/*
*********************************************
AUTHOR: Tim Keefer
DATE: Mon May  2 11:25:43 CDT 2005

CSS SECTIONS:
1. Main - Main Document Structure	
2. Side Navigation
3. Header Nav Styles
4. Misc. Styles
	a. box styles
	b. table styles
*********************************************
/* 
*********************************************
START: Main document structure
*********************************************
*/
input {
    border: 1px solid #777;
    background: dce2da;
}
a {
    color: #333;
}
a:active {
    color: #ddd;
}
a:hover {
    color: blue;
}

#user_content {
  width: 150px;
  margin: 0 0 10px 0;
}

#products {
  width: 150px;
  margin: 0 0 10px 0;
}

#product_attribs {
  width: 150px;
  margin: 0 0 10px 0;
}

#users {
  width: 150px;
  margin: 0 0 10px 0;
}

#user_content ul {
    list-style: none;
    margin: 0;
    padding: 0;
}

#products ul {
    list-style: none;
    margin: 0;
    padding: 0;
}

#product_attribs ul {
    list-style: none;
    margin: 0;
    padding: 0;
}

#users ul {
    list-style: none;
    margin: 0;
    padding: 0;
}

#site_links {
    visibility: hidden;
}

#footer #site_links {
    visibility: visible;
}
fieldset {    
    background: #e9e9e9;
    border: 1px solid #c7c7c7;
}

legend {
    padding: 0 10px 0 10px;
    border: 1px solid #c7c7c7;
    background: #fff;
}

#content .box table {
    padding: 0;
    margin: 0;
    background: #eee;
    width: 100%;
}

#content .box table td {
    padding: 0 4px 0 4px;
    margin: 0;
    border: 0;
}

#content .box table tr {
    background: #b9c5b4;
}

#content .box table tr + tr {
    background: #fff;
}

#footer {
    font: normal 12px/20px sans-serif;
    text-align: center;
    padding: 10px;
    margin: 0px auto ;
    width: 740px;
}

#float_right {
    float: right;
}

#float_left {
    float: left;
}

#right {
    text-align: right;
}
body {
    margin: 0;
    background: #eee;
    font-family: sans-serif;
    font-size: 100%;
}

#header {
    background: #fff;
    margin: 0px auto 0px auto;
    border-bottom: 1px solid #778;
}

#page {
    background: #fff; url(/images/logos/corner.png) no-repeat bottom right;
    width: 740px;
    margin: 0 auto;
    padding: 0px 0px 0px 0px;
    border: 1px solid #c7c7c7;
    border-top: 0;
}

#content {
    background: #fff;
    margin: 0px 0px 0px 0px;
    padding: 10px 10px 10px 10px;
    font: normal 12px/20px sans-serif;
    /* border-right: 1px dotted #99d; */
}
#title_bar {
    clear: both;
    border: 1px solid #c7c7c7;
    background: #b9c5b4;
    width: 740px;
    text-align: center;
    padding: 3px 0 0 0;
    margin: 0 auto 0 auto;
    -moz-border-radius-topright: 6px;
}


#nav {
    background: #eee;
    margin: 0px auto 0px auto;
    padding: 0px;
    width: 742px;
}
#nav ul {
    background: #fff;
    list-style: none;
    border: 0;
    margin: 0 0 0 0 ;
    padding: 0;
}
#nav ul li {
    display: block;
    float: left;
    text-align: center;
    padding: 0;
    margin: 0;
    border-left: 1px solid #99d;
}#nav ul li + li {
    border-left: none;
    display: block;
    float: left;
    text-align: center;
    padding: 0;
    margin: 0;
}
#nav ul li a {
    background: #fff;
    border-bottom: 1px solid #99d;
    border-right: 1px solid #99d;
    border-left: none;
    padding: 0 8px 0 8px;
    margin: 0 0 0px 0;
    color: #9a9a9a;
    text-decoration: none;
    display: block;
    text-align: center;
    font: normal 12px/20px sans-serif;
}
#nav ul li a:hover {
    color: #000;
    background: #bbe;
}

#nav a:active {
    background: #c60;
    color: #fff;
}

#nav li strong a {
    background: #bbf;
    font-weight: bold;
    color: #000;
}
.lowtech {
    visibility: hidden;
}
