package Gantry::Samples::Model;
use strict; use warnings;

use base 'DBIx::Class::Schema';

use Gantry::Samples::GENModel;

sub get_db_options {
    return { AutoCommit => 1 };
}

1;

=head1 NAME

Gantry::Samples::Model - schema class for Gantry::Samples

=head1 SYNOPSIS

In your base module:

    use Gantry::Samples::Model;
    sub schema_base_class { return 'Gantry::Samples::Model'; }
    use Gantry::Plugins::DBIxClassConn qw( get_schema );

=head1 DESCRIPTION

This module was generated by Bigtop.  But, feel free to edit it.  You
might even want to update these docs.

=over 4

=item get_db_options

The generated version sets AutoCommit to 1, this assumes that you will
do all transaction work via the DBIx::Class API.

=back

=head1 DEPENDENCIES

    Gantry::Utils::DBIxClass
    Gantry::Samples::GENModel

=head1 AUTHOR

Timotheus Keefer, E<lt>tkeefer@apple.comE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2006 Timotheus Keefer

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.6 or,
at your option, any later version of Perl 5 you may have available.

=cut
