package JobAd;

use strict;

our $VERSION = '0.01';

use base 'GENJobAd';

use JobAd::Job;
use JobAd::Skill;
use JobAd::Position;
use JobAd::AuthUsers;
use JobAd::AuthGroups;
use JobAd::AuthGroupMembers;
use JobAd::AuthPages;

1;

=head1 NAME

JobAd - the base module of this web app

=head1 SYNOPSIS

This package is meant to be used in a stand alone server/CGI script or the
Perl block of an httpd.conf file.

Stand Alone Server or CGI script:

    use JobAd;

    my $cgi = Gantry::Engine::CGI->new( {
        config => {
            #...
        },
        locations => {
            '/' => 'JobAd',
            #...
        },
    } );

httpd.conf:

    <Perl>
        # ...
        use JobAd;
    </Perl>

If all went well, one of these was correctly written during app generation.

=head1 DESCRIPTION

This module was originally generated by Bigtop.  But feel free to edit it.
You might even want to describe the table this module controls here.

=head1 METHODS (inherited from GENJobAd)

=over 4

=item init

=item do_main

=item site_links


=back


=head1 SEE ALSO

    Gantry
    GENJobAd
    JobAd::Job
    JobAd::Skill
    JobAd::Position
    JobAd::AuthUsers
    JobAd::AuthGroups
    JobAd::AuthGroupMembers
    JobAd::AuthPages

=head1 AUTHOR

Phil Crow, E<lt>pcrow@localdomainE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2006 Phil Crow

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.6 or,
at your option, any later version of Perl 5 you may have available.

=cut
