package JobAd::Model::job_skill;
use strict; use warnings;

use base 'Gantry::Utils::DBIxClass', 'Exporter';

use JobAd::Model::GEN::job_skill;

our $JOB_SKILL = 'JobAd::Model::job_skill';

our @EXPORT_OK = ( '$JOB_SKILL' );

1;

=head1 NAME

JobAd::Model::job_skill - model for job_skill table (stub part)

=head1 DESCRIPTION

This model inherits from its generated helper, which inherits from
Gantry::Utils::DBIxClass.  It was generated by Bigtop, but is
NOT subject to regeneration.

=cut
