package JobAd::Model::auth_groups;
use strict; use warnings;

use base 'Gantry::Utils::DBIxClass', 'Exporter';

use JobAd::Model::GEN::auth_groups;

our $AUTH_GROUPS = 'JobAd::Model::auth_groups';

our @EXPORT_OK = ( '$AUTH_GROUPS' );

1;

=head1 NAME

JobAd::Model::auth_groups - model for auth_groups table (stub part)

=head1 DESCRIPTION

This model inherits from its generated helper, which inherits from
Gantry::Utils::DBIxClass.  It was generated by Bigtop, but is
NOT subject to regeneration.

=head1 METHODS (mixed in from JobAd::Model::GEN::auth_groups)

You may use all normal Gantry::Utils::DBIxClass methods and the
ones listed here:

=over 4

=item get_foreign_display_fields

=item get_foreign_tables

=item foreign_display

=item table_name

=back

=cut
